// Some functions for CGI processing...
#ifndef RH_CGI_H
#define RH_CGI_H 1

#include <string>
#include <map>
#include <list>

using namespace std;

typedef map<string const,string> strlist;
typedef map<string const,string>::iterator striterator;
typedef list<string> stringlist;

/** Class for CGI handling - parsing of parameters etc.
  */
class CGI {
public:
	/** Method (as in <form method="something">)
	  */
	enum Method { AUTO, POST, GET };
	/** Constructor - create a CGI object to start parsing etc.
	  * @param m Method used by the web page calling us.
	  * Defaults to autodetection.
	  */
	CGI(Method m=AUTO);
	~CGI();

	/** Get the value of a parameter. If, for example, the calling page
	  * used <input type="text" name="something" />, use
	  * getpar("something") to get what the user entered.
	  * @param name of parameter (name tag of the input field)
	  * @return value supplied by user or empty string if invalid
	  */
	string const getpar(string const par);

	/** translate CGI input to what the user meant (get rid of %XX and +)
	  * @param s string as passed to us by webserver
	  * @return decoded string
	  */
	string translate(string s);

	/** Get a list of all variables that were passed to the CGI
	  * @return stringlist containing all variable names that were
	  * passed to us
	  */
	stringlist variables() { return vars; };

	/** Get a list of all parameters (keys+values) that were passed
	  * to the CGI
	  * @return strlist containing all variables that were passed to us
	  */
	strlist parameters() { return parameter; };

private:
	/** split the query string into the various parameters it contains
	  * for internal use (by the constructor) only.
	  * @param parameters the query string
	  */
	void parse(string parameters);

	strlist parameter;
	stringlist vars;
};

#endif
