// Some functions for HTML generation...
#ifndef RH_HTML_H
#define RH_HTML_H 1

#include <string>
#include <map>
#include <list>

using namespace std;

class form;
typedef list<string> stringlist;

/** Class for HTML code generation
  */
class HTML {
	friend ostream &operator << (ostream &os, HTML &h);
public:
	/** Constructor - create an empty HTML page
	  * @param title title of page, default: empty
	  * @param bodywhite white background in <body>
	  * @param description description of page, default: empty
	  * @param keywords keywords for page, default: empty
	  * @param address e-mail address of generator, default: empty
	  * @param encoding charset of page, default: iso-8859-1
	  * @param generator name of generation program, default: Bero CGI library
	  * @param extrahdr extra header fields, default: empty
	  * @param hasend true if </body></html> should be added at the
	  *        end (on by default). Turn this of when you're generating
	  *        a server-side include or something like that.
	  * @param hashead true if the page has a header (on by default).
	  *        Turn this off when you're generating a server-side
	  *        include or something like that.
	  */
	HTML(string title="", bool bodywhite=true, string description="",
			string keywords="", string address="",
			string encoding="iso-8859-1",
			string generator="Bero CGI library",
			string extrahdr="", bool hasend=true,
			bool hashead=true);
	~HTML();

	/** Add some text (may or may not include HTML tags)
	  */
	void addText(string txt);
	
	/** Add a form to the HTML page.
	  * @param form form (as generated by the form class)
	  */
	void addForm(form &f);

	/** Add a Server-Side Include (this is specific to Apache)
	  * @param name name of file to be included
	  */
	void addSSI(string name);

        /** New line
	  */
	void newLine();

	/** Add a horizontal separator line (<hr />)
	  */
	void addLine();

	/** Add an image
	  * @param filename file name
	  * @param alt Text to be displayed in text-only browsers, defaults to filename
	  * @param width width of image (may be omitted)
	  * @param height height of image (may be omitted)
	  */
	void addImage(string filename, string alt="", int width=-1, int height=-1);

protected:
	stringlist head;
	stringlist header;
	stringlist stylesheet;
	stringlist body;
	stringlist end;
};

#include "form.h"

ostream &operator << (ostream &os, HTML &h);
ostream &operator << (ostream &os, stringlist &s);

#endif
